## 91VPS IP API SDK - Node.js

通过 SDK 可快速调用 91VPS IP 支持的 API 接口

### <u>简介</u>

91VPS IP - Api SDK (NodeJs 版本)

### <u>依赖环境</u>

1. sync-request

   ```NodeJs
   npm install sync-request
   ```

2. express (运行测试案例时需要安装,如果不需要测试则无需安装)

   ```NodeJS
   npm install express
   ```

3. 从[巨量 IP](https://www.91vps.com/)购买相应的产品

4. 获取订单的[trade_no(业务号)](http://www.91vps.com/users/product/time) 和对应的 [Key(业务秘钥)](http://www.juliangip.com/users/product/quantity)

### <u>获取安装</u>

安装 nodeJs SDK 之前, 请先获取订单所对应的业务编号(trade_no)和业务对应的秘钥(Key). 订单编号时用于识别具体业务订单, Key 则是用于加密签名字符串和服务器端用于验证签名一致性的秘钥. 因此,业务秘钥必须严格保管,避免泄露,一旦泄露,请立即前往个人中心 ——>[产品管理](http://www.juliangip.com/users/http) 页面进行对应业务订单的秘钥重置.

### <u>通过 npm 安装(推荐)</u>

如果您的项目环境未配置 npm,可前往[NodeJs](https://nodejs.org/zh-cn/) 官网下载并安装合适的 NodeJs 版本,然后可参考下方示例进行安装:

- Ubuntu 安装 npm :

  ```shell
  1.获取安装源,在终端中执行
  curl -sL https://deb.nodesource.com/setup_17.0.1 | sudo -E bash -
  2.等待源添加完毕后在执行
  sudo apt-get install -y nodejs
  3.验证安装
  node -v:查看node版本
  ```

- CentOS 安装 npm :

  ```shell
  1.使用wget拉取源文件
  wget https://npm.taobao.org/mirrors/node/v17.0.1/node-v17.0.1-linux-x64.tar.gz
  2.执行tar -zxvf 执行解压缩命令
  tar -xvf node-v17.0.1-linux-x64.tar.gz
  3.验证安装
  node -v:查看node版本
  ```

- MacOS 安装 npm :

  ```shell
  1.打开终端，执行以下命令安装Homebrew
  ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"
  2.安装node
  brew install node   //sudo 使用admin权限
  3.验证安装
  node -v:查看node版本
  ```

### 启动命令

```javascript
$ cd sdk
$ npm i sync-request
$ npm i express
$ node API/server.js (执行开启http端口监听的js文件)
```

### <u>示例</u>

```js
//导入 Node.js Web 应用程序开发框架 -- express
const express = require("express");
const app = express();
// 引入body-parser模块
const bodyParser = require("body-parser");
const Client = require("./clients");
let client = new Client();

app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: false }));
const dyTradeNo = "dyTradeNo trade_no";
const dyKey = "dyKey accesskey";
const kpsTradeNo = "alone trade_no";
const kpsKey = "alone accesskey";
const unlimitedTradeNo = "unlimitedTradeNo trade_no";
const unlimitedKey = "unlimitedKey accesskey";
const postPayTradeNo = "postpay trade_no";
const postPayKey = "postPayKey accesskey";

let result = ""; //用于接收返回值的参数

//启动程序监听3600端口
app.listen(3600, () => {
  console.log("server start --> port : 3600");
});

app.get("/", (req, resp) => {
  resp.send("91VPS IP API 示例");
});

/**
 * 动态代理 -- 提取代理IP示例
 * @param {业务秘钥} key <必传参数>
 * @param {业务号} trade_no <必传参数>
 * @param {提取数量} num <必传参数>
 * @param {可选参数
 *  pt : 代理类型,
 *  result_type : 返回类型('text' | 'json' | 'xml')
 *  split : 结果分隔符,
 *  city_name : 地区名称,
 *  city_code : 邮政编码,
 *  ip_remain : 剩余可用时长,
 *  area : 筛选地区,
 *  filter : IP去重
 * } otherParams <可选参数>
 * @param {HTTP请求方式} method
 */
app.use("/dynamic/getIps", (req, resp) => {
  /**
   * 动态代理 -- 提取代理IP示例
   */
  result = client.dynamicGetIps(dyKey, dyTradeNo, 5, {
    pt: 2,
    result_type: "json",
    city_name: 1,
  });
  console.log(result);
  resp.send(result);
});

app.use("/dynamic/getIps", (req, resp) => {
  result = client.dynamicGetIps(dyKey, dyTradeNo, 5, {
    pt: 2,
    result_type: "json",
    city_name: 1,
  });
  console.log(result);
  resp.send(result);
});
```

### <u>参考资料</u>

- [产品文档](http://www.91vps.com/help)
- [快速入门](http://www.91vps.com/http/api)
- [API 接口](http://www.91vps.com/http/api)
